/*
 * (c) Copyright 2007 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License.
 *
 * For redistributing this software or a derivative work under a license other
 * than the GPL-compatible Free Software License as defined by the Free
 * Software Foundation or approved by OSI, you must first obtain a commercial
 * license to this software product from Volker Bergmann.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.commons.tree;

import org.databene.commons.TreeModel;

/**
 * Default implementation of a {@link TreeModel}. It uses DefaultTreeNodes.<br/>
 * <br/>
 * Created: 08.05.2007 19:05:14
 * @author Volker Bergmann
 */
public class DefaultTreeModel<E> implements TreeModel<DefaultTreeNode<E>> {

    private DefaultTreeNode<E> root;

    public DefaultTreeModel(DefaultTreeNode<E> root) {
        this.root = root;
    }

    public DefaultTreeNode<E> getRoot() {
        return root;
    }

    public DefaultTreeNode<E> getParent(DefaultTreeNode<E> child) {
        return child.getParent();
    }

    public DefaultTreeNode<E> getChild(DefaultTreeNode<E> parent, int index) {
        return parent.getChild(index);
    }

    public int getChildCount(DefaultTreeNode<E> parent) {
        return parent.getChildCount();
    }

    public boolean isLeaf(DefaultTreeNode<E> node) {
        return node.isLeaf();
    }

    public int getIndexOfChild(DefaultTreeNode<E> parent, DefaultTreeNode<E> child) {
        return parent.getIndexOfChild(child);
    }
}
